@@ -5,6 +5,7 @@ import logging
 import re
 import sys
 from distutils.version import StrictVersion
+from importlib_resources import read_text
 from subprocess import run
 
 import redis
@@ -13,18 +14,14 @@ from prompt_toolkit.shortcuts import clear
 from redis.connection import Connection, SSLConnection, UnixDomainSocketConnection
 from redis.exceptions import AuthenticationError, ConnectionError, TimeoutError
 
-from . import markdown, project_data, renders
-from .commands_csv_loader import (
-    all_commands,
-    command2callback,
-    commands_summary,
-    groups,
-)
+from . import markdown, renders
+from .data import commands as commands_data
+from .commands import command2callback, commands_summary, groups, split_command_args
 from .completers import IRedisCompleter
 from .config import config
 from .exceptions import NotRedisCommand
 from .renders import OutputRender
-from .utils import compose_command_syntax, nativestr, split_command_args, exit
+from .utils import compose_command_syntax, nativestr, exit
 from .warning import confirm_dangerous_command
 
 logger = logging.getLogger(__name__)
@@ -237,7 +234,7 @@ class Client:
             )
         logger.info(f"[Prepare command] Redis: {redis_command}, Shell: {shell_command}")
         try:
-            command_name, args = split_command_args(redis_command, all_commands)
+            command_name, args = split_command_args(redis_command)
             logger.info(f"[Split command] command: {command_name}, args: {args}")
             input_command_upper = command_name.upper()
             # Confirm for dangerous command
@@ -357,15 +354,12 @@ class Client:
         command_docs_name = "-".join(args).lower()
         command_summary_name = " ".join(args).upper()
         try:
-            doc_file = open(project_data / "commands" / f"{command_docs_name}.md")
+            doc = read_text(commands_data, f"{command_docs_name}.md")
         except FileNotFoundError:
             raise NotRedisCommand(
                 f"{command_summary_name} is not a valide Redis command."
             )
-
-        with doc_file as doc_file:
-            doc = doc_file.read()
-            rendered_detail = markdown.render(doc)
+        rendered_detail = markdown.render(doc)
         summary_dict = commands_summary[command_summary_name]
 
         avaiable_version = summary_dict.get("since", "?")
